#ifndef __LANG_H__
#define __LANG_H__

#include <hildon/hildon.h>

typedef struct
{
	char* str_short;
	char* str_long;
} language;

language languages[51] = {
	{ "af", "Afrikaans" },
	{ "sq", "Albanian" },
	{ "ar", "Arabic" },
	{ "be", "Belarusian" },
	{ "bg", "Bulgarian" },
	{ "ca", "Catalan" },
	{ "zh-CN", "Chinese" },
	{ "hr", "Croatian" },
	{ "cs", "Czech" },
	{ "da", "Danish" },
	{ "nl", "Dutch" },
	{ "en", "English" },
	{ "et", "Estonia" },
	{ "tl", "Filipino" },
	{ "fi", "Finnish" },
	{ "fr", "French" },
	{ "gl", "Galician" },
	{ "de", "German" },
	{ "el", "Greek" },
	{ "iw", "Hebrew" },
	{ "hi", "Hindi" },
	{ "hu", "Hungarian" },
	{ "is", "Icelandic" },
	{ "id", "Indonesian" },
	{ "ga", "Irish" },
	{ "it", "Italian" },
	{ "ja", "Japanese" },
	{ "ko", "Korean" },
	{ "lv", "Latvian" },
	{ "lt", "Lithuanian" },
	{ "mk", "Mecedonian" },
	{ "ms", "Malay" },
	{ "mt", "Maltese" },
	{ "no", "Norwegian" },
	{ "fa", "Persian" },
	{ "pl", "Polish" },
	{ "pt", "Portuguese" },
	{ "ro", "Romanian" },
	{ "ru", "Russian" },
	{ "sr", "Serbian" },
	{ "sk", "Slovak" },
	{ "sl", "Slovenian" },
	{ "es", "Spanish" },
	{ "sw", "Swahili" },
	{ "sv", "Swedish" },
	{ "th", "Thai" },
	{ "tr", "Turkish" },
	{ "uk", "Ukrainian" },
	{ "vi", "Vietnamese" },
	{ "cy", "Welsh" },
	{ "yi", "Yiddish" }
};

#endif /* __LANG_H__ */
